Quantity of Money Theory 
======================== 
 
This section includes planned models related to the Quantity of Money Theory. Contributions are welcome! 
 
- Fisher Equation 
- Cambridge Equation 
- Velocity of Money Models 
- Quantity Theory of Money (QTM) 
- Money Demand Function (Md) 
